@@ -47,7 +47,9 @@ def make_region(coordinates, width: int, resolution: int):
 
 
 class Oracle:
-    def __init__(self, loop_list_path: str, hic_file: str, models_dir: str, norm: str, width: int = 56,chr_list : list = None):
+    def __init__(self, loop_list_path: str,
+                 hic_file: str, models_dir: str, norm: str,
+                 width: int = 56, chr_list: list = None):
         self.__loopList = self.load_loops(loop_list_path)
         self.__hic = hs.HiCFile(hic_file)
         self.__norm = norm
@@ -55,13 +57,13 @@ class Oracle:
         self.__modelsDir = models_dir
         self.__resolutions = sorted(find_resolutions_from_list(self.__loopList))
         self.__resolution_sub_lists = make_resolution_sub_lists(self.__loopList)
-        self.__chr = self.makeChrList(chr_list)
+        self.__chr = self.make_chr_list(chr_list)
         self.__model = tf.keras.models.load_model(self.__modelsDir)
 
-    def makeChrList(self,chrList):
-        if chrList is None:
-          return [x.name for x in self.__hic.getChromosomes() if x.name!='All']
-        return [str(x) for x in chrList]
+    def make_chr_list(self, chr_list):
+        if chr_list is None:
+            return [x.name for x in self.__hic.getChromosomes() if x.name != 'All']
+        return [str(x) for x in chr_list]
 
     @staticmethod
     def load_loops(loop_list):
@@ -85,48 +87,47 @@ class Oracle:
         m = np.tanh(scale * (matrix - median_val) / mad_val)
         return (m - m.min()) / (m.max() - m.min())
 
-    def makePredictions(self,chr):
+    def make_predictions(self, chromosome):
         passed, failed = [], []
-        for reso,sublist in self.__resolution_sub_lists.items():
-          print ('ORACLE is running at', reso, 'kb', 'on', chr)
+        for reso, sublist in self.__resolution_sub_lists.items():
+            print('ORACLE is running at', reso, 'kb', 'on', chromosome)
 
-          if len(failed)>0:
-            # failed.drop(['prediction'],axis=1,inplace=True)
-            failed = failed.loc[:,~failed.columns.str.contains('^score_oracle_', case=False)] 
-            sublist = pd.concat([sublist,failed], ignore_index = True)
-          
-          sublist = sublist[sublist['chr1']==chr]
-          sublist = sublist.reset_index(drop=True)
-          batch = np.zeros((len(sublist),self.__width,self.__width,1))
+            if len(failed) > 0:
+                # failed.drop(['prediction'],axis=1,inplace=True)
+                failed = failed.loc[:, ~failed.columns.str.contains('^score_oracle_', case=False)]
+                sublist = pd.concat([sublist, failed], ignore_index=True)
 
-          mzd = self.__hic.getMatrixZoomData(chr, chr, "observed", self.__norm , "BP", reso)
-          for index, row in sublist.iterrows():   
-            x1,x2,y1,y2 = make_region((row[CHROM_KEY],row[X1_KEY],row[X2_KEY],row[Y1_KEY],row[Y2_KEY]),self.__width-1,reso)
-            mat = mzd.getRecordsAsMatrix(x1,x2,y1,y2)
+            sublist = sublist[sublist['chr1'] == chromosome]
+            sublist = sublist.reset_index(drop=True)
+            batch = np.zeros((len(sublist), self.__width, self.__width, 1))
 
-            batch[index,:self.__width-1,:self.__width-1,0] = self.preprocess(mat)
-          prediction = self.__model.predict(batch)
-          sublist['score_oracle_'+str(reso)] = prediction.reshape(prediction.shape[0],)
-          psd = sublist[sublist['score_oracle_'+str(reso)] >= 0.5]
-          passed.append(psd)
-          failed = sublist[sublist['score_oracle_'+str(reso)] < 0.5]
-          print (psd.shape[0],'calls passed ORACLE.')
-          print (failed.shape[0], 'calls failed ORACLE.')
-          # psd.to_csv(filename + '_ORACLE_passed_'+str(reso)+'.bedpe', sep="\t", index=False)
-          # failing.to_csv(filename + '_ORACLE_failed_'+str(reso)+'.bedpe', sep="\t", index=False)
+            mzd = self.__hic.getMatrixZoomData(chromosome, chromosome, "observed", self.__norm, "BP", reso)
+            for index, row in sublist.iterrows():
+                x1, x2, y1, y2 = make_region((row[CHROM_KEY], row[X1_KEY], row[X2_KEY], row[Y1_KEY], row[Y2_KEY]),
+                                             self.__width - 1, reso)
+                mat = mzd.getRecordsAsMatrix(x1, x2, y1, y2)
 
+                batch[index, :self.__width - 1, :self.__width - 1, 0] = self.preprocess(mat)
+            prediction = self.__model.predict(batch)
+            sublist['score_oracle_' + str(reso)] = prediction.reshape(prediction.shape[0], )
+            psd = sublist[sublist['score_oracle_' + str(reso)] >= 0.5]
+            passed.append(psd)
+            failed = sublist[sublist['score_oracle_' + str(reso)] < 0.5]
+            print(psd.shape[0], 'calls passed ORACLE.')
+            print(failed.shape[0], 'calls failed ORACLE.')
+            # psd.to_csv(filename + '_ORACLE_passed_'+str(reso)+'.bedpe', sep="\t", index=False)
+            # failing.to_csv(filename + '_ORACLE_failed_'+str(reso)+'.bedpe', sep="\t", index=False)
 
-        return (pd.concat(passed,ignore_index = True).fillna('.'), failed)
-
+        return pd.concat(passed, ignore_index=True).fillna('.'), failed
 
     def run(self):
-        passed,failed = [],[]
+        passed, failed = [], []
         for chrom in self.__chr:
-          preds = self.makePredictions(chrom)
-          passed.append(preds[0])
-          failed.append(preds[1])
+            prediction = self.make_predictions(chrom)
+            passed.append(prediction[0])
+            failed.append(prediction[1])
 
-        return (pd.concat(passed,ignore_index = True).fillna('.'), pd.concat(failed,ignore_index=True))
+        return pd.concat(passed, ignore_index=True).fillna('.'), pd.concat(failed, ignore_index=True)
 
 
 # python3 oracle.py <file.hic> </dir/models> </dir/bedpe> <norm>
@@ -136,10 +137,10 @@ if __name__ == "__main__":
     MODEL_DIR = sys.argv[2]
     BEDPE_DIR = sys.argv[3]
     NORMALIZATION_TYPE = sys.argv[4]
-    if len(sys.argv)<6:
-      CHR_LIST = ['All']
+    if len(sys.argv) < 6:
+        CHR_LIST = ['All']
     else:
-      CHR_LIST = sys.argv[5].split(',')
+        CHR_LIST = sys.argv[5].split(',')
 
     oracle = Oracle(BEDPE_DIR, FILEPATH, MODEL_DIR, NORMALIZATION_TYPE, chr_list=CHR_LIST)
     passing, failing = oracle.run()
